FamiljeLiv.se
Description: Sveriges största mötesplats för vuxna, med fokus på familjelivet, förälder, graviditet och barn.

Gå till startsidan
Kom ihåg mig Glömt ditt lösenord?
Bli medlem Logga in via Facebook

- Start
- Forum
  - Forum
    - Senaste inläggen
    - Skapa en ny tråd
    - Mina favoriter
    - Mina trådar
    - Grupper
  - Kategorier
    - Adoption
    - Ekonomi & juridik
    - Familjeliv.se
    - Fritid & hobby
    - Fråga experten
  - 5
    - Förälder
    - Gravid
    - Hus & hem
    - Husdjur
    - Kropp & själ
  - 10
    - Känsliga rummet
    - Nöje
    - Pappagrupp
    - Planerar barn
    - Samhälle
  - 15
    - Sandlådan
    - Sex & samlevnad
    - Svårt att få barn
    - änglarum
- Bloggar
  - Bloggar
    - Föräldrafitness
    - Helt enkelt Fi
    - Lidingömamman
    - Lisa Abefelt
    - Malin Wollin
    - Vårt dagliga vuxenkrux
- Planerar barn
- Väntar barn
- Förälder
- Övrigt
  - Övrigt
    - Clearblue
    - Fråga experten
    - Första tiden hemma
    - Lekliv
    - Matliv
    - Min förlossning
    - Pampers
    - Resliv
    - Semper
    - Webb-TV

‹›

- Ny toppbloggare på Familjeliv. Säg hej till underbara Fi Lindfors
- Julbonus – på allt.Julhandla och få bonus rätt in på bankkontot.
- Upptakt till årets största helg. Boosta dig med skön julkänsla
- Office 365, det enda kontorsprogrammet du och din familj behöver

Ägglossningskalender

Graviditetsuträknare

Gravidkalender

Fråga experten

### GOD JUL

### Upptakt till årets största helg. Boosta dig med skön julkänsla

Allt du behöver för den perfekta julen.

### Slut på trassel

### Ingen mer gråt eller bråk när håret ska tvättas på kvällen

Kampanj - 18 nov
Familjeliv i samarbete med Natusan.
Publicerad 18 november 2014 Uppdaterad 20 november 2014

### LEKAR

### Pepparkaksrull för barn med spring i benen

Colossus Jul - 2 dec
Perfekt motion efter julmaten
Publicerad 2 december 2014 Uppdaterad 3 december 2014

### VACCINATION

### Pernilla Wahlgren delar med sig av sitt första ögonblick med Bianca

Kampanj - 2 dec
I samarbete med Pampers-UNICEF
Publicerad 2 december 2014 Uppdaterad 2 december 2014

### JULKALENDER

### Vinn fina & lyxiga priser varje dag ända fram till jul i kalendern

I samarbete med LEGO.

### Djurrätt

### Djurvänligare jul med Sveriges största djurrättsorganisation

Kampanj - 27 nov
I samarbete med Djurens Rätt.
Publicerad 27 november 2014 Uppdaterad 1 december 2014

### BLOGG

### Satsa vegetariskt idag: Så gör du Elminas grönsakspannkakor

Gör kvällens middag till en grön fest.

### BLOGG

### Nykter och stolt. Därför valde Thess Järvheden bort alkoholen

"Jag tyckte för mycket om alkohol".

### musikal

### Musikalen Evita berättar historien om Eva Peron och hennes liv

Kampanj - 18 nov
I samarbete med Göta Lejon.
Publicerad 18 november 2014 Uppdaterad 3 december 2014

### VACCINATION

### Det räcker med tre doser stelkrampsvaccin.

#### Familjeliv i samarbete med UNICEF

Förälder - 24 nov
Familjeliv i samarbete med UNICEF
Publicerad 24 november 2014 Uppdaterad 26 november 2014

### BILDEXTRA

### Kommer du ihåg alla de senaste årens julklappar?

Colossus Jul - 25 nov
Årets julklapp 2014 är utsedd.
Publicerad 25 november 2014 Uppdaterad 3 december 2014

### FORUM

###
Jag älskar julen, nästan lite sjukt

Här möts vi i forumet som älskar julen

### DIAKONIA

### Julklappar och lussebullar är inte verklighet för alla barn

Kampanj - 28 nov
I Samarbete med Diakonia.
Publicerad 28 november 2014 Uppdaterad 10 december 2014

### Familjeliv i samarbete med Viaplay

### Med Viaplay kan du alltid pausa ditt favoritprogram

Viaplay - 16 apr
För middag, tandborstning eller läxor.
Publicerad 16 april 2014 Uppdaterad 27 november 2014

### WEBB-TV

### Så gör du munsbitar med Nutella, hasselnötter och choklad

Lisa Abefelt guidar dig i julgodisbaket.

### JULKLAPPAR

### Så undviker du intern tävling vid julklappsutdelningen

Colossus Jul - 3 dec
Bromsa julklappshetsen i år.
Publicerad 3 december 2014 Uppdaterad 3 december 2014

### utveckling

### Så hjälper du ditt barn att utveckla sin motorik

Pampers - 2 dec
Familjeliv i samarbete med Pampers
Publicerad 2 december 2013 Uppdaterad 16 oktober 2014

### WEBB-TV

### Tagit fram samma julgranskulor som alla andra år? Dekorera dem nya!

Lisa Abefelt pysslar steg för steg.

### PODD

### Missa inte det senaste poddavsnittet. Snabba dig in och lyssna redan idag.

#### Familjeliv i samarbete med Pampers

Förälder - 16 okt
Lyssna här
Publicerad 16 oktober 2013 Uppdaterad 10 december 2014

### VINTERN KOMMER

### Tänk på det här när barnen ska kläs för kylan

Förälder - 2 dec
Familjeliv reder ut begreppen.
Publicerad 2 december 2014 Uppdaterad 3 december 2014

### Vaccination

### Alla önskar sitt barn en hälsosam start på livet oavsett var man bor

Pampers - 29 okt
Familjeliv i samarbete med Pampers.
Publicerad 29 oktober 2014 Uppdaterad 5 november 2014

### UR ARKIVET

### Jag hämnades och gjorde slut med min mans älskarinna via sms

"Hur ska jag göra nu?"

### BLOGG

### Ny toppbloggare på Familjeliv. Säg hej till underbara Fi Lindfors

Förälder - 10 dec
Sockerknarkande och yogafrälst.
Publicerad 10 december 2014 Uppdaterad 10 december 2014

### HÅLLBARHET

### Bland giftiga kemikalier och farliga material: Välj rätt basplagg

Kampanj - 3 nov
Familjeliv i samarbete med Make It Last.
Publicerad 3 november 2014 Uppdaterad 4 november 2014

### BLOGG

### Så gör du godaste adventstårtan med smak av saffran & lingon

Blogg-Lisa guidar dig genom receptet.

### inredning

### Sätt guldkant på vardagen med hållbara detaljer.

Kampanj - 3 nov
Familjeliv i samarbete med Åhléns
Publicerad 3 november 2014 Uppdaterad 3 november 2014

### NOSTALGITRIPP

### Vilken av alla julkalendrar i SVT är din favorit?

#### Psst - orkar du inte bläddra hela bildspelt - bläddra bakåt

Colossus Jul - 25 nov
Vi har samat alla i nostalgiskt bildspel.
Publicerad 25 november 2013 Uppdaterad 3 december 2014

### JULEFRID

### Så undviker du att stressen tar kål på barnens julaktiviteter

Colossus Jul - 1 dec
Tänk så här istället
Publicerad 1 december 2014 Uppdaterad 3 december 2014

### Vaccination

### Alla önskar sitt barn en hälsosam start på livet oavsett var man bor

Pampers - 29 okt
Familjeliv i samarbete med Pampers.
Publicerad 29 oktober 2014 Uppdaterad 5 november 2014

### BLOGG

### Så gör du godaste adventstårtan med smak av saffran & lingon

Blogg-Lisa guidar dig genom receptet.

### förälder

### Första tiden hemma med bebis

Dela med dig med din egen berättelse eller läs andramedlemmars

### BLOGG

### Det har aldrig någonsin varit enklare att starta en lyxigt fin blogg

Starta din nya blogg nu.

### BILDEXTRA

### Kommer du ihåg alla de senaste årens julklappar?

Colossus Jul - 25 nov
Årets julklapp 2014 är utsedd.
Publicerad 25 november 2014 Uppdaterad 3 december 2014

### barnvagnar

### 10 populäraste duovagnarna oktober. Se hela listan

Kampanj - 15 okt
Familjeliv i samarbete med Prisjakt.se
Publicerad 15 oktober 2014 Uppdaterad 15 oktober 2014

### Expert

### Ställ din fråga direkt till barnmorskan i expertforumet

Få svar från barnmorskan Aleksandra här.

### BLOGG

### Träningsexperten Elmina bloggar om mammaträning.

Kampanj - 19 nov
Läe mer om Elmina här
Publicerad 19 november 2014 Uppdaterad 24 november 2014

### BLOGG

### Järvheden: ”Vad gör väl en rundspark eller två mitt i natten?"

En röst i natten om kärlek och sömn.

### utveckling

### Ett stort steg när barnet tar sina första steg, men när händer det?

Pampers - 4 dec
Familjeliv i samarbete med Pampers
Publicerad 4 december 2013 Uppdaterad 10 oktober 2014

### ARKIVET

### Sambon äter upp akvariefiskarna. Försvunnit många ur akvariet

Läs medlemmarnas råd.
217
"Jaha heter hon SÅ, det var ju speciellt..." Klass-diskussion ang dotters namn..
88
Ställ in julen, bonus är ju inte här:(
180
Mobbingen mot SD
46
Min man runkar med vårt barn bredvid sig
118
Dagis/dagmamma redan från 3 månader, är det så förfärligt?
38
Lämna förhållande pga hans dotter?
21
18 år och gillade sex med pappa
41
Små bröst, är missnöjd! (bild)
51
Har ni kvinnor håriga rövar?
49
styvmamma ärva pappa?
12047
Jag längtar till jul!!!
2263
Vi som gör äggdonation hösten/vintern 2013/2014
3
Vet inte vad som händer, hur kan jag hjälpa honom?
118
Dagis/dagmamma redan från 3 månader, är det så förfärligt?
11
Hade du stannat kvar?!
88
Ställ in julen, bonus är ju inte här:(
2013
Bf Maj 2015
0
Hej
1560
Tempar/Fertility friend
46
i vilken vecka födde du första barnet. ?
Mina vågade bilder
30555
Mina bilder
13766
Kämpartjejerna
368
Öppna gruppen
3729
35 plus - Wonabee Preggos Wonabees
448
Sexfantasier
0
Jävlaasylmissbrukarkramandekommunistvåldsvänsterjävel 2
41
30-plustrådarnas samlingspunkt
20219
Lekkamraterna-privat
7689
VÄRDGRUPPEN MINA BILDER
613

### Senaste Artiklar

- Senaste Artiklar

  Ny toppbloggare på Familjeliv. Säg hej till underbara Fi Lindfors
  Rubrik
  Så klär du ditt barn bäst när det blir kallt
  3 doser stelkrampsvaccin räcker!
  Var fjärde 2-åring använder surfplatta. Varningstexter behövs
  De föräldrar som är så rädda och arga över andras sjuka barn är ofta värst själva
  Lycklig besökare: ”Fy fan säger jag! Hur roligt får man ha?”
  15 vanligaste tecknen på att du kan vara gravid

### Hetaste debatterna

"Jaha heter hon SÅ, det var ju speciellt..." Klass-diskussion ang dotters namn.. Ställ in julen, bonus är ju inte här:( Mobbingen mot SD Min man runkar med vårt barn bredvid sig Dagis/dagmamma redan från 3 månader, är det så förfärligt?